jacinle.image.backend
=====================

.. automodule:: jacinle.image.backend

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      imread
      imshow
      imwrite
      opencv_only
      opencv_or_pil
      pil_img2nd
      pil_nd2img
      pil_only
      resize
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: imread

.. autofunction:: imshow

.. autofunction:: imwrite

.. autofunction:: opencv_only

.. autofunction:: opencv_or_pil

.. autofunction:: pil_img2nd

.. autofunction:: pil_nd2img

.. autofunction:: pil_only

.. autofunction:: resize


